@@ -110,7 +110,7 @@ impl Parse for ComponentFunction {
                     ReturnType::Default => {
                         return Err(syn::Error::new_spanned(
                             sig,
-                            "function must return `sycamore::template::Template`",
+                            "function must return `sycamore::view::View`",
                         ))
                     }
                     ReturnType::Type(_, ty) => ty,
@@ -168,7 +168,7 @@ pub fn component_impl(
     let component_name_str = component_name.to_string();
     let generic_node_ty = generic_node_ty.type_params().next().unwrap();
     let generic_node: GenericParam = syn::parse_quote! {
-        #generic_node_ty: ::sycamore::generic_node::GenericNode
+        #generic_node_ty: ::sycamore::generic_node::Html
     };
 
     let ComponentFunction {
@@ -177,17 +177,29 @@ pub fn component_impl(
         arg,
         mut generics,
         vis,
-        attrs,
+        mut attrs,
         name,
         return_type,
     } = component;
 
+    let mut doc_attrs = Vec::new();
+    let mut i = 0;
+    while i < attrs.len() {
+        if attrs[i].path.is_ident("doc") {
+            // Attribute is a doc attribute. Remove from attrs and add to doc_attrs.
+            let at = attrs.remove(i);
+            doc_attrs.push(at);
+        } else {
+            i += 1;
+        }
+    }
+
     let prop_ty = match &arg {
         FnArg::Receiver(_) => unreachable!(),
         FnArg::Typed(pat_ty) => &pat_ty.ty,
     };
 
-    // Add the GenericNode type param to generics.
+    // Add the Html type param to generics.
     let first_generic_param_index = generics
         .params
         .iter()
@@ -205,11 +217,18 @@ pub fn component_impl(
     let (impl_generics, ty_generics, where_clause) = generics.split_for_impl();
 
     // Generics for the PhantomData.
-    let phantom_generics = ty_generics
-        .clone()
-        .into_token_stream()
-        .into_iter()
-        .collect::<Vec<_>>();
+    let phantom_generics = {
+        // Filter out generics which are not types
+        let mut generics = generics.clone();
+        generics.params = generics
+            .params
+            .into_iter()
+            .filter(|x| matches!(x, GenericParam::Type(_)))
+            .collect();
+
+        let (_, generics, _) = generics.split_for_impl();
+        generics.into_token_stream().into_iter().collect::<Vec<_>>()
+    };
     // Throw away first and last TokenTree to get rid of angle brackets.
     let phantom_generics_len = phantom_generics.len();
     let phantom_generics = phantom_generics
@@ -226,7 +245,7 @@ pub fn component_impl(
     }
 
     let quoted = quote! {
-        #(#attrs)*
+        #(#doc_attrs)*
         #vis struct #component_name#generics {
             #[doc(hidden)]
             _marker: ::std::marker::PhantomData<(#phantom_generics)>,
@@ -239,7 +258,8 @@ pub fn component_impl(
             const NAME: &'static ::std::primitive::str = #component_name_str;
             type Props = #prop_ty;
 
-            fn __create_component(#arg) -> #return_type{
+            #(#attrs)*
+            fn create_component(#arg) -> #return_type{
                 #block
             }
         }
