@@ -1,12 +1,12 @@
 use sycamore::prelude::*;
 
 #[component(Comp1<G>)]
-fn comp1() -> Template<G> {
+fn comp1() -> View<G> {
     todo!();
 }
 
 #[component(Comp2<G>)]
-fn comp2(_props: ()) -> Template<G> {
+fn comp2(_props: ()) -> View<G> {
     todo!();
 }
 
